import { Jwt } from './jwt';
import { WindowRef } from '../window-ref';
export declare class Cookie {
    key: string;
    value: string;
    constructor(key: string, value: string);
}
/**
 * This service is used to get the user context in which an SPA is being used.
 * Note: If your SPA is organization based, you might want to use Context service instead.
 *
 * Ideally, it should be included as part of your providers in your app.component file so all the application has access to it.
 * Its dependencies must be provided in app.component as well.
 * So, your app.component.ts should look something like this
 *
 * ```
 * import { Location } from '@angular/common';
 * import { Component } from '@angular/core';
 * import { HTTP_PROVIDERS } from '@angular/http';
 * import { APP_CONFIG, ContextService, Client, IAppConfig, WindowRef } from 'ng2-ue-utils';
 *
 * import { MyMainComponent } from './route/to/myMainComponent';
 *
 * const appConfig: IAppConfig = {
 *   apiBasePath: 'myapibasepath',
 *   appBasePath: 'myappbasepath',
 *   gtmAppName: 'nameforgoogletagmanager'
 * };
 *
 * @Component({
 *   directives: [
 *       MyMainComponent
 *   ],
 *   providers: [
 *       ContextHelper,
 *       WindowRef,
 *       { provide: APP_CONFIG, useValue: appConfig }
 *   ],
 *   selector: 'app',
 *   template: '<myMainComponent-or-routerOutlet></myMainComponent-or-routerOutlet>'
 * })
 * export class AppComponent {}
 * ```
 *
 * The most common usage for this service is to set the context of the user for GTM.
 * To do that create it in the component or service constructor and use it as follows
 *
 * ```
 *  constructor (
 *      @Inject(APP_CONFIG) appConfig: IAppConfig,
 *      window: WindowRef) {
 *          this.helper = new ContextHelper(window, appConfig.gtmAppName);
 *      }
 *
 *  // to be called in a good place on your flow
 *  private setContext () {
 *      const userName = this.helper.getUser();
 *      const userId = this.helper.getUuid();
 *      this.helper.updateGtmContext('', userId, userName);
 *  }
 * ```
 *
 */
export declare class ContextHelper {
    private window;
    private gtmAppName;
    constructor(window: WindowRef, gtmAppName: string);
    orgNameFromPath(path: string): string;
    orgNameFromLocal(): string;
    orgNameToLocal(name: string): void;
    updateGtmContext(orgName?: string, uuid?: string, email?: string): void;
    cookies(): Cookie[];
    cookie(key: string): string;
    accessToken: () => string;
    jwt: () => Jwt;
    getUser: () => string;
    getUuid: () => string;
}
