"use strict";
var jwt_1 = require('./jwt');
var Cookie = (function () {
    function Cookie(key, value) {
        this.key = key;
        this.value = value;
    }
    return Cookie;
}());
exports.Cookie = Cookie;
/**
 * This service is used to get the user context in which an SPA is being used.
 * Note: If your SPA is organization based, you might want to use Context service instead.
 *
 * Ideally, it should be included as part of your providers in your app.component file so all the application has access to it.
 * Its dependencies must be provided in app.component as well.
 * So, your app.component.ts should look something like this
 *
 * ```
 * import { Location } from '@angular/common';
 * import { Component } from '@angular/core';
 * import { HTTP_PROVIDERS } from '@angular/http';
 * import { APP_CONFIG, ContextService, Client, IAppConfig, WindowRef } from 'ng2-ue-utils';
 *
 * import { MyMainComponent } from './route/to/myMainComponent';
 *
 * const appConfig: IAppConfig = {
 *   apiBasePath: 'myapibasepath',
 *   appBasePath: 'myappbasepath',
 *   gtmAppName: 'nameforgoogletagmanager'
 * };
 *
 * @Component({
 *   directives: [
 *       MyMainComponent
 *   ],
 *   providers: [
 *       ContextHelper,
 *       WindowRef,
 *       { provide: APP_CONFIG, useValue: appConfig }
 *   ],
 *   selector: 'app',
 *   template: '<myMainComponent-or-routerOutlet></myMainComponent-or-routerOutlet>'
 * })
 * export class AppComponent {}
 * ```
 *
 * The most common usage for this service is to set the context of the user for GTM.
 * To do that create it in the component or service constructor and use it as follows
 *
 * ```
 *  constructor (
 *      @Inject(APP_CONFIG) appConfig: IAppConfig,
 *      window: WindowRef) {
 *          this.helper = new ContextHelper(window, appConfig.gtmAppName);
 *      }
 *
 *  // to be called in a good place on your flow
 *  private setContext () {
 *      const userName = this.helper.getUser();
 *      const userId = this.helper.getUuid();
 *      this.helper.updateGtmContext('', userId, userName);
 *  }
 * ```
 *
 */
var ContextHelper = (function () {
    function ContextHelper(window, gtmAppName) {
        var _this = this;
        this.window = window;
        this.gtmAppName = gtmAppName;
        this.accessToken = function () { return _this.cookie('access_token'); };
        this.jwt = function () { return new jwt_1.Jwt(_this.accessToken()); };
        this.getUser = function () { return _this.jwt().user; };
        this.getUuid = function () { return _this.jwt().uuid; };
    }
    ContextHelper.prototype.orgNameFromPath = function (path) {
        var parts = /^\/(?:o|organizations)\/([^\/]+)\//.exec(path);
        if (parts && parts.length > 1) {
            return parts[1];
        }
    };
    ContextHelper.prototype.orgNameFromLocal = function () {
        var name = this.window.getLocal('organization');
        // Ensure it is undefined instead of null.
        if (!name && name !== undefined) {
            name = undefined;
        }
        return name;
    };
    ContextHelper.prototype.orgNameToLocal = function (name) {
        this.window.setLocal('organization', name);
    };
    ContextHelper.prototype.updateGtmContext = function (orgName, uuid, email) {
        var context = {
            'organization.name': orgName,
            'webapp.name': this.gtmAppName,
            'event': 'Push Context'
        };
        if (/^[^@]+@apigee.com/.test(email || '')) {
            context['user.internal'] = 'internal';
        }
        if (uuid) {
            context['user.uuid'] = uuid;
        }
        if (email) {
            context['user.email'] = email;
        }
        this.window.gtmContext(context);
    };
    ContextHelper.prototype.cookies = function () {
        var docCookie = this.window.cookies();
        if (docCookie) {
            return docCookie.split(';').map(function (c) {
                var pair = c.split('=');
                if (pair.length >= 2) {
                    return { key: pair[0].trim(), value: pair[1].trim() };
                }
                return { key: c, value: c };
            });
        }
        return [];
    };
    ContextHelper.prototype.cookie = function (key) {
        var c = this.cookies().find(function (cc) { return cc.key === key; });
        if (c) {
            return c.value;
        }
    };
    return ContextHelper;
}());
exports.ContextHelper = ContextHelper;
//# sourceMappingURL=context-helper.js.map